==> uxkit-0.0.2.tgz: package/built/UXKit/ActionSheet.js <==
/// <reference path="../../typings/tsd.d.ts"/>
import * as React from "react";
import { View } from "./View";
import { ViewController } from "./ViewController";
import { PixelLine } from "./PixelLine";
import { TextButton } from "./Button";
import { TapGestureRecognizer } from "./GestureRecognizer";
import { PresetColor } from "./Types";
import { ControlEvents, GestureRecognizerState } from "./Enum";
/**
 * AlertView
 */
export class ActionSheet extends ViewController {
    constructor(props) {
        super(props);
        this.buttonTitles = [];
        this.reversedIndexes = [];
        this.dangerIndexes = [];
        this.cancelButtonIndex = -1;
        // Private
        this.alphaPresented = false;
        this.contentPresented = false;
        this.buttonTitles = props.buttonTitles;
        this.reversedIndexes = props.reversedIndexes;
        this.cancelButtonIndex = props.cancelButtonIndex;
        this.handler = props.handler;
        this.cancelGesture = new TapGestureRecognizer((state) => {
            if (this.props.cancelButtonIndex >= 0 && state == GestureRecognizerState.Ended) {
                this.props.handler && this.props.handler(this.props.cancelButtonIndex);
                this.dismissViewController(false);
            }
        });
    }
    static show(inViewController, buttonTitles = ["OK"], cancelButtonIndex = 0, handler) {
        inViewController.presentViewController(ActionSheet, {
            buttonTitles: buttonTitles,
            cancelButtonIndex: cancelButtonIndex,
            handler: handler,
        }, false);
    }
    loadView() {
        let buttons = [];
        for (let i = 0; i < this.props.buttonTitles.length; i++) {
            if (i < this.props.buttonTitles.length) {
                buttons.push(React.createElement(PixelLine, {key: "separator_" + i}));
            }
            var buttonTitle = this.props.buttonTitles[i];
            buttons.push(React.createElement(TextButton, {frame: { height: 60 }, title: buttonTitle, key: "button_" + i, tag: i, tintColor: PresetColor.mainTextColor, backgroundColor: i == this.props.cancelButtonIndex ? "#f8f8f8" : "white", handler: (event, sender) => {
                if (event == ControlEvents.TouchUpInside) {
                    this.props.handler && this.props.handler(sender.props.tag);
                    this.dismissViewController(false);
                }
            }}));
        }
        return (React.createElement(View, {frame: { x: 0, y: 0, mx: 0, my: 0 }, animatable: true, gestureRecognizers: [this.cancelGesture], backgroundColor: "#00000090", alpha: this.alphaPresented ? 1.0 : 0.0}, React.createElement(View, {animatable: true, frame: { x: 0, mx: 0, my: (this.contentPresented ? 0 : this.props.buttonTitles.length * -60) }}, buttons)));
    }
    viewWillAppear() {
        View.setAnimate(() => {
            this.alphaPresented = true;
            this.setState({});
        }, 500);
        setTimeout(() => {
            View.setAnimate(() => {
                this.contentPresented = true;
                this.setState({});
            }, 500, 'spring', { friction: 30.0, tension: 400.0, toValue: 0.0 });
        }, 100);
    }
    dismissViewController(animated) {
        View.setAnimate(() => {
            this.contentPresented = false;
            this.setState({});
        }, null, 'spring', { friction: 20.0, tension: 600.0, toValue: 0.0 });
        setTimeout(() => {
            View.setAnimate(() => {
                this.alphaPresented = false;
                this.setState({});
            }, 200, 'timing', null, () => {
                super.dismissViewController(false);
            });
        }, 100);
    }
}
ActionSheet.defaultProps = {
    style: {
        backgroundColor: "#ffffff00"
    },
};

==> uxkit-0.0.3.tgz: package/built/UXKit/ActionSheet.js <==
/// <reference path="../../typings/tsd.d.ts"/>
import * as React from "react";
import { View } from "./View";
import { ViewController } from "./ViewController";
import { PixelLine } from "./PixelLine";
import { TextButton } from "./Button";
import { TapGestureRecognizer } from "./GestureRecognizer";
import { PresetColor } from "./Types";
import { ControlEvents, GestureRecognizerState } from "./Enum";
/**
 * AlertView
 */
export class ActionSheet extends ViewController {
    constructor(props) {
        super(props);
        this.buttonTitles = [];
        this.reversedIndexes = [];
        this.dangerIndexes = [];
        this.cancelButtonIndex = -1;
        // Private
        this.alphaPresented = false;
        this.contentPresented = false;
        this.buttonTitles = props.buttonTitles;
        this.reversedIndexes = props.reversedIndexes;
        this.cancelButtonIndex = props.cancelButtonIndex;
        this.handler = props.handler;
        this.cancelGesture = new TapGestureRecognizer((state) => {
            if (this.props.cancelButtonIndex >= 0 && state == GestureRecognizerState.Ended) {
                this.props.handler && this.props.handler(this.props.cancelButtonIndex);
                this.dismissViewController(false);
            }
        });
    }
    static show(inViewController, buttonTitles = ["OK"], cancelButtonIndex = 0, handler) {
        inViewController.presentViewController(React.createElement(ActionSheet, {buttonTitles: buttonTitles, cancelButtonIndex: cancelButtonIndex, handler: handler}), false);
    }
    loadView() {
        let buttons = [];
        for (let i = 0; i < this.props.buttonTitles.length; i++) {
            if (i < this.props.buttonTitles.length) {
                buttons.push(React.createElement(PixelLine, {key: "separator_" + i, bottom: 0}));
            }
            var buttonTitle = this.props.buttonTitles[i];
            buttons.push(React.createElement(TextButton, {frame: { height: 60 }, title: buttonTitle, key: "button_" + i, tag: i, tintColor: PresetColor.mainTextColor, backgroundColor: i == this.props.cancelButtonIndex ? "#f8f8f8" : "white", handler: (event, sender) => {
                if (event == ControlEvents.TouchUpInside) {
                    this.props.handler && this.props.handler(sender.props.tag);
                    this.dismissViewController(false);
                }
            }}));
        }
        return (React.createElement(View, {frame: { x: 0, y: 0, mx: 0, my: 0 }, animatable: true, gestureRecognizers: [this.cancelGesture], backgroundColor: "#00000090", alpha: this.alphaPresented ? 1.0 : 0.0}, React.createElement(View, {animatable: true, frame: { x: 0, mx: 0, my: (this.contentPresented ? 0 : this.props.buttonTitles.length * -60) }}, buttons)));
    }
    viewWillAppear() {
        View.setAnimate(() => {
            this.alphaPresented = true;
            this.setState({});
        }, 500);
        setTimeout(() => {
            View.setAnimate(() => {
                this.contentPresented = true;
                this.setState({});
            }, 500, 'spring', { friction: 30.0, tension: 400.0, toValue: 0.0 });
        }, 100);
    }
    dismissViewController(animated) {
        View.setAnimate(() => {
            this.contentPresented = false;
            this.setState({});
        }, null, 'spring', { friction: 20.0, tension: 600.0, toValue: 0.0 });
        setTimeout(() => {
            View.setAnimate(() => {
                this.alphaPresented = false;
                this.setState({});
            }, 200, 'timing', null, () => {
                super.dismissViewController(false);
            });
        }, 100);
    }
}
ActionSheet.defaultProps = {
    style: {
        backgroundColor: "#ffffff00"
    },
};
